@@ -3,7 +3,7 @@ import logging
 
 from bibtexparser.bibdatabase import BibDatabase
 
-from .clean_bib_file import replace_duplicates
+from .clean_bib_file import replace_duplicate_ids, remove_duplicate_entries
 from .modernize_bib_file import replace_bib_id
 from .util import load_bib_file
 
@@ -16,7 +16,7 @@ def combine_bib_entries(bib_entries):
 
 
 
-def combine_bib_files_main(bib_files, allow_duplicates=False,
+def combine_bib_files_main(bib_files, allow_duplicates=False, force=False,
                            replace_ids=False, verbose=logging.WARN, 
                            encoding='utf-8'):
     logging.basicConfig(format="%(asctime)s - [%(levelname)8s]: %(message)s")
@@ -28,8 +28,10 @@ def combine_bib_files_main(bib_files, allow_duplicates=False,
     bib_databases = [load_bib_file(_bib_file, abbr=None, encoding=encoding)
                      for _bib_file in bib_files]
     combined_entries = combine_bib_entries(bib_databases)
+    combined_entries = remove_duplicate_entries(combined_entries, force=force, verbose=verbose)
+    logger.debug("Successfully removed duplicates")
     #if replace_ids:
     #    combined_entries = #TODO: Adjust modernize function to support lists as input
     if not allow_duplicates:
-        combined_entries = replace_duplicates(combined_entries)
+        combined_entries = replace_duplicate_ids(combined_entries)
     return combined_entries
