@@ -8,3 +8,6 @@ KEY_EPRINT = "eprint"
 KEY_ARCHIVE = "archiveprefix"
 KEY_CATEGORY = "primaryclass"
 KEY_ENTRYTYPE = "ENTRYTYPE"
+KEYS_JOURNAL = ["journal", "journaltitle"]
+KEY_BOOKTITLE = "booktitle"
+KEY_EDITOR = "editor"
